```
Usage: vcd catalog acl remove [OPTIONS] <catalog-name> [ACCESS_LIST]...

Options:
  --all       remove all the access settings from the catalog
  -y, --yes
  -h, --help  Show this message and exit.

```
